# Installation

![](../img/heroes/dont_panic.png)


## Requirements

Marvin requires Python 3.9+.
## For normal use
To install Marvin, run `pip install marvin`. As a matter of best practice, we recommend installing Marvin in a [virtual environment](https://realpython.com/python-virtual-environments-a-primer/).

To use Marvin's [knowledge features](../guide/concepts/infra.md), please include the [Chroma](https://www.trychroma.com/) dependency: `pip install marvin[chromadb]`.

Before using Marvin, you'll need to [configure your OpenAI API key](openai.md).

## For development

To install Marvin for development, please see the [development guide](../development/development.md).